@@ -1,24 +1,25 @@
-/*
- *  Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
+/* This file is part of Spectacle, the KDE screenshot utility
+ * Copyright (C) 2015 Boudhayan Gupta <bgupta@kde.org>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU Lesser General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef SPECTACLEDBUSADAPTER_H
-#define SPECTACLEDBUSADAPTER_H
+#pragma once
 
 #include <QDBusAbstractAdaptor>
 #include "SpectacleCore.h"
@@ -60,7 +61,7 @@ class SpectacleDBusAdapter: public QDBusAbstractAdaptor
     public:
 
     SpectacleDBusAdapter(SpectacleCore *parent);
-    virtual ~SpectacleDBusAdapter();
+    virtual ~SpectacleDBusAdapter() = default;
 
     inline SpectacleCore *parent() const;
 
@@ -78,5 +79,3 @@ class SpectacleDBusAdapter: public QDBusAbstractAdaptor
     void ScreenshotTaken(const QString &fileName);
     void ScreenshotFailed();
 };
-
-#endif // SPECTACLEDBUSADAPTER_H
